@@ -1,6 +1,3 @@
-# TODO
-# consider to include a sub "find" in PNI that return a preloaded instance of PNI::Finder
-# and finder will be not a singleton anymore, but will be a PNI::Item
 package PNI::Finder;
 use strict;
 use Module::Pluggable search_path => 'PNI::Node', require => 1, inner => 0;
@@ -8,13 +5,13 @@ use Module::Pluggable search_path => 'PNI::Node', require => 1, inner => 0;
 # this class is a singleton
 my $self;
 
-# return $self
+# return $self : PNI::Finder
 sub instance {
     if ( not defined $self ) {
         # it was 
         # $self = bless \__PACKAGE__, __PACKAGE__;
         # but it is not supported by perl 5.8, see bug id=69733
-        $self = bless \my $v, __PACKAGE__;
+        $self = bless \my $singleton, __PACKAGE__;
     }
     return $self;
 }
@@ -33,12 +30,23 @@ __END__
 
 PNI::Finder - searches for available nodes
 
+=head1 SYNOPSIS
+
+    my $find = PNI::Finder->instance;
+    my @node_list = $find->nodes;
+
 =head1 METHODS
 
 =head2 C<instance>
 
+    my $find = PNI::Finder->instance
+
+Returns the only instance of this class.
+
 =head2 C<nodes>
 
+    $find->nodes
+
 Returns a list of available PNI nodes, i.e. every package under the PNI::Node
 namespace that is a valid PNI::Node, minus the leading 'PNI::Node::' string.
 
